@@ -60,7 +60,22 @@ opendate = list(caldate[caldate["is_open"] == 1]["cal_date"])
 opendate_set = set(opendate)  # for speed checking?
 
 # fund code list which always round down for the purchase share approximation
-droplist = ["003318", "000311"]
+droplist = ["003318", "000311", "000601", "009989"]
+
+
+def calendar_selfcheck():
+    # 国内链接 githubusercontent.com 大概率存在问题，因此设计成联网自动更新日历大概率无用。
+    # 也许之后考虑一些较稳定的第三方资源托管服务
+    current_year = dt.datetime.now().year
+    if str(current_year) != opendate[-1][:4]:
+        logger.warning(
+            "Please update xalpha via `pip install -U xalpha` to keep the trade calendar up-to-date"
+        )
+        print("请更新 xalpha 版本以更新最新年份的 A 股交易日历, 否则将可能无法正确获取和处理最新的基金净值")
+
+
+calendar_selfcheck()
+
 
 region_trans = {
     "瑞士": "CH",
@@ -94,6 +109,15 @@ holidays = {
         "2020-12-25",
         "2020-12-28",
         "2020-12-31",
+        "2021-01-01",
+        "2021-01-26",
+        "2021-04-02",
+        "2021-04-05",
+        "2021-06-14",
+        "2021-12-24",
+        "2021-12-27",
+        "2021-12-28",
+        "2021-12-31",
     ],
     "CH": [
         "2020-01-01",
@@ -106,6 +130,13 @@ holidays = {
         "2020-12-24",
         "2020-12-25",
         "2020-12-31",
+        "2021-01-01",
+        "2021-04-02",
+        "2021-04-05",
+        "2021-05-13",
+        "2021-05-24",
+        "2021-12-24",
+        "2021-12-31",
     ],
     "CN": [
         "2020-01-01",
@@ -127,6 +158,24 @@ holidays = {
         "2020-10-06",
         "2020-10-07",
         "2020-10-08",
+        "2021-01-01",
+        "2021-02-11",
+        "2021-02-12",
+        "2021-02-15",
+        "2021-02-16",
+        "2021-02-17",
+        "2021-04-05",
+        "2021-05-03",
+        "2021-05-04",
+        "2021-05-05",
+        "2021-06-14",
+        "2021-09-20",
+        "2021-09-21",
+        "2021-10-01",
+        "2021-10-04",
+        "2021-10-05",
+        "2021-10-06",
+        "2021-10-07",
     ],
     "DE": [
         "2020-01-01",
@@ -137,6 +186,12 @@ holidays = {
         "2020-12-24",
         "2020-12-25",
         "2020-12-31",
+        "2021-01-01",
+        "2021-04-02",
+        "2021-04-05",
+        "2021-05-24",
+        "2021-12-24",
+        "2021-12-31",
     ],
     "FR": [
         "2020-01-01",
@@ -146,6 +201,11 @@ holidays = {
         "2020-12-24",
         "2020-12-25",
         "2020-12-31",
+        "2021-01-01",
+        "2021-04-02",
+        "2021-04-05",
+        "2021-12-24",
+        "2021-12-31",
     ],
     "HK": [
         "2020-01-01",
@@ -161,6 +221,22 @@ holidays = {
         "2020-10-02",
         "2020-10-26",
         "2020-12-25",
+        "2021-01-01",
+        "2021-02-11",
+        "2021-02-12",
+        "2021-02-15",
+        "2021-04-02",
+        "2021-04-05",
+        "2021-04-06",
+        "2021-05-19",
+        "2021-06-14",
+        "2021-07-01",
+        "2021-09-22",
+        "2021-10-01",
+        "2021-10-14",
+        "2021-12-24",
+        "2021-12-27",
+        "2021-12-31",
     ],
     "IN": [
         "2020-02-21",
@@ -175,6 +251,19 @@ holidays = {
         "2020-11-16",
         "2020-11-30",
         "2020-12-25",
+        "2021-01-26",
+        "2021-03-11",
+        "2021-03-29",
+        "2021-04-02",
+        "2021-04-14",
+        "2021-04-21",
+        "2021-05-13",
+        "2021-07-20",
+        "2021-08-19",
+        "2021-09-10",
+        "2021-10-15",
+        "2021-11-04",
+        "2021-11-19",
     ],
     "JP": [
         "2020-01-01",
@@ -196,6 +285,22 @@ holidays = {
         "2020-11-03",
         "2020-11-23",
         "2020-12-31",
+        "2021-01-01",
+        "2021-01-11",
+        "2021-02-11",
+        "2021-02-23",
+        "2021-04-29",
+        "2021-05-03",
+        "2021-05-04",
+        "2021-05-05",
+        "2021-07-22",
+        "2021-07-23",
+        "2021-08-09",
+        "2021-09-20",
+        "2021-09-23",
+        "2021-11-03",
+        "2021-11-23",
+        "2021-12-31",
     ],
     "KR": [
         "2020-01-01",
@@ -210,6 +315,16 @@ holidays = {
         "2020-10-09",
         "2020-12-25",
         "2020-12-31",
+        "2021-01-01",
+        "2021-02-11",
+        "2021-02-12",
+        "2021-03-01",
+        "2021-05-05",
+        "2021-05-19",
+        "2021-09-20",
+        "2021-09-21",
+        "2021-09-22",
+        "2021-12-31",
     ],
     "SG": [
         "2020-01-01",
@@ -223,6 +338,17 @@ holidays = {
         "2020-12-24",
         "2020-12-25",
         "2020-12-31",
+        "2021-01-01",
+        "2021-02-11",
+        "2021-02-12",
+        "2021-04-02",
+        "2021-05-13",
+        "2021-05-26",
+        "2021-07-20",
+        "2021-08-09",
+        "2021-11-04",
+        "2021-12-24",
+        "2021-12-31",
     ],
     "TW": [
         "2020-01-01",
@@ -242,6 +368,23 @@ holidays = {
         "2020-10-01",
         "2020-10-02",
         "2020-10-09",
+        "2021-01-01",
+        "2021-02-08",
+        "2021-02-09",
+        "2021-02-10",
+        "2021-02-11",
+        "2021-02-12",
+        "2021-02-15",
+        "2021-02-16",
+        "2021-03-01",
+        "2021-04-02",
+        "2021-04-05",
+        "2021-04-30",
+        "2021-06-14",
+        "2021-09-20",
+        "2021-09-21",
+        "2021-10-11",
+        "2021-12-31",
     ],
     "UK": [
         "2020-01-01",
@@ -255,6 +398,17 @@ holidays = {
         "2020-12-28",
         "2020-12-31",
         "2021-01-01",
+        "2021-01-01",
+        "2021-04-02",
+        "2021-04-05",
+        "2021-05-03",
+        "2021-05-31",
+        "2021-08-30",
+        "2021-12-24",
+        "2021-12-27",
+        "2021-12-28",
+        "2021-12-31",
+        "2022-01-03",
     ],
     "US": [
         "2020-01-01",
@@ -271,6 +425,18 @@ holidays = {
         "2020-12-24",
         "2020-12-25",
         "2021-01-01",
+        "2021-01-01",
+        "2021-01-18",
+        "2021-02-15",
+        "2021-03-14",
+        "2021-04-02",
+        "2021-05-31",
+        "2021-07-05",
+        "2021-09-06",
+        "2021-11-07",
+        "2021-11-25",
+        "2021-11-26",
+        "2021-12-24",
     ],
 }
 
@@ -383,8 +549,7 @@ def convert_date(date):
 def _date_check(dtobj, check=False):
     if not isinstance(dtobj, dt.datetime):
         dtobj = dt.datetime.strptime(dtobj.replace("/", "").replace("-", ""), "%Y%m%d")
-    if check and (dtobj.year > 2020 or dtobj.year < 1991):
-        # TODO: remember change 2020 every year!
+    if check and (dtobj.year > dt.datetime.now().year or dtobj.year < 1991):
         raise ValueError(
             "date goes beyond market range: %s" % dtobj.strftime("%Y-%m-%d")
         )
@@ -433,12 +598,12 @@ def _float(n):
             logger.info("_float met -, taken as 0")
             return 0
         elif n.endswith("%"):
-            logger.warning("_float met with % as %s" % n)
-            return float(n[:-1] / 100)
+            logger.info("_float met with %% as %s" % n)
+            return float(n[:-1]) / 100
     except AttributeError:
         pass
     if not n:
-        logger.warning("_float met with None as input arguments")
+        logger.info("_float met with None as input arguments")
         return 0.0
     return float(n)
 
