@@ -523,27 +523,55 @@ class indicator:
             return line
 
 
-def plot_kline(df, rendered=True, col=""):
+def plot_kline(
+    df,
+    rendered=True,
+    ucolor="#ef232a",
+    dcolor="#14b143",
+    ucolorborder=None,
+    dcolorborder=None,
+    ucolorvolume=None,
+    dcolorvolume=None,
+    col="",
+):
     """
     针对 dataframe 直接画出标准看盘软件的上k线图下成交量图的形式
 
     :param df:
     :param rendered:
+    :param ucolor: str for color when going up, default red in A stock as "#ef232a"
+    :param dcolor: str for color when going down, default green in A stock as "#14b143"
     :param col:
     :return:
     """
+    # TODO: color changing seems to make no effect, possible issue with pyecharts
+    if ucolorborder is None:
+        ucolorborder = ucolor
+    if dcolorborder is None:
+        dcolorborder = dcolor
+    if ucolorvolume is None:
+        if ucolor != "#ffffff":
+            ucolorvolume = ucolor
+        else:
+            ucolorvolume = ucolorborder
+    if dcolorvolume is None:
+        if dcolor != "#ffffff":
+            dcolorvolume = dcolor
+        else:
+            dcolorvolume = dcolorborder
+
     kline = (
         Kline()
         .add_xaxis(xaxis_data=list(df["date"]))
         .add_yaxis(
             series_name="",
             itemstyle_opts=opts.ItemStyleOpts(
-                color="#ef232a",
-                color0="#14b143",
-                border_color="#ef232a",
-                border_color0="#14b143",
+                color=ucolor,
+                color0=dcolor,
+                border_color=ucolorborder,  # ucolor,
+                border_color0=dcolorborder,  # dcolor,
             ),
-            y_axis=list(zip(df["open"], df["close"], df["high"], df["low"])),
+            y_axis=list(zip(df["open"], df["close"], df["low"], df["high"])),
             markpoint_opts=opts.MarkPointOpts(
                 data=[
                     opts.MarkPointItem(type_="max", name="最大值"),
@@ -579,19 +607,20 @@ def plot_kline(df, rendered=True, col=""):
             ),
         )
     )
-    if col:
-        line = (
-            Line()
-            .add_xaxis(xaxis_data=list(df["date"]))
-            .add_yaxis(
-                series_name="",
-                y_axis=list(df[col]),
-                is_smooth=True,
-                linestyle_opts=opts.LineStyleOpts(opacity=0.5),
-                label_opts=opts.LabelOpts(is_show=False),
+    if col is not None:
+        for c in col:
+            line = (
+                Line()
+                .add_xaxis(xaxis_data=list(df["date"]))
+                .add_yaxis(
+                    series_name=c,
+                    y_axis=list(df[c]),
+                    is_smooth=True,
+                    linestyle_opts=opts.LineStyleOpts(opacity=0.5),
+                    label_opts=opts.LabelOpts(is_show=False),
+                )
             )
-        )
-        kline = kline.overlap(line)
+            kline = kline.overlap(line)
 
     if "volume" in df.columns:
         vl = list(df["volume"])
@@ -610,17 +639,19 @@ def plot_kline(df, rendered=True, col=""):
             itemstyle_opts=opts.ItemStyleOpts(
                 color=JsCode(
                     """
-                function(params) {
+                function(params) {{
                     var colorList;
-                    if (barData[params.dataIndex]>0) {
-                        colorList = '#ef232a';
-                    } else {
-                        colorList = '#14b143';
-                    }
+                    if (barData[params.dataIndex]>0) {{
+                        colorList = '{ucolor}';
+                    }} else {{
+                        colorList = '{dcolor}';
+                    }}
                     return colorList;
-                }
-                """
-                )
+                }}
+                """.format(
+                        ucolor=ucolorvolume, dcolor=dcolorvolume
+                    )
+                )  # escape {} when using format
             ),
         )
         .set_global_opts(
