@@ -869,7 +869,7 @@ def get_bond_rates(rating, date=None):
     """
     rating = rating.strip()
     rating_uid = {
-        "N": "2c9081e50a2f9606010a3068cae70001",
+        "N": "2c9081e50a2f9606010a3068cae70001",  # 国债
         "AAA": "2c9081e50a2f9606010a309f4af50111",
         "AAA-": "8a8b2ca045e879bf014607ebef677f8e",
         "AA+": "2c908188138b62cd01139a2ee6b51e25",
@@ -878,6 +878,11 @@ def get_bond_rates(rating, date=None):
         "A+": "2c9081e91b55cc84011be40946ca0925",
         "A": "2c9081e91e6a3313011e6d438a58000d",
         "A-": "8a8b2ca04142df6a014148ca880f3046",
+        "A": "2c9081e91e6a3313011e6d438a58000d",
+        "BBB+": "2c9081e91ea160e5011eab1f116c1a59",
+        "BBB": "8a8b2ca0455847ac0145650780ad68fb",
+        "BB": "8a8b2ca0455847ac0145650ba23b68ff",
+        "B": "8a8b2ca0455847ac0145650c3d726901",
     }
     # 上边字典不全，非常欢迎贡献 ：）
     def _fetch(date):
@@ -1583,9 +1588,21 @@ def get_rt_from_ttjj(code):
             ),
             str(s.findAll("dt")[1]).split("(")[1].split(")")[0][7:],
         )
-        estimate = s.select("#gz_gsz")[0].text
+        estimate = s.select("span[id=gz_gsz]")[0].text  # after loading
         if estimate == "--":
-            estimate = None
+            gsz = rget(
+                "http://fundgz.1234567.com.cn/js/{code}.js".format(code=code),
+                headers={
+                    "Host": "fundgz.1234567.com.cn",
+                    "Referer": "http://fund.eastmoney.com/",
+                },
+            )
+            try:  # in case eval error
+                gsz_dict = eval(gsz.text[8:-2])
+                estimate = _float(gsz_dict["gsz"])
+                estimate_time = gsz_dict["gztime"]
+            except:
+                estimate = None
         else:
             try:
                 estimate = _float(estimate)
@@ -1601,7 +1618,10 @@ def get_rt_from_ttjj(code):
     status = s.select("span[class='staticCell']")[0].text.strip()
     tb = s.select("div.infoOfFund > table >tr>td")
     infol = [i.text for i in tb]
-
+    try:
+        estimate_time
+    except NameError:
+        estimate_time = None
     return {
         "name": name,
         "time": date,
@@ -1615,6 +1635,7 @@ def get_rt_from_ttjj(code):
         "manager": infol[2].split("：")[1],
         "company": infol[4].split("：")[1],
         "estimate": estimate,
+        "estimate_time": estimate_time,
     }
     # 是否有美元份额计价的基金会出问题？
 
@@ -2645,7 +2666,15 @@ class vinfo(basicinfo, indicator):
     """
 
     def __init__(
-        self, code, name=None, start=None, end=None, rate=0, col="close", **kws
+        self,
+        code,
+        name=None,
+        start=None,
+        end=None,
+        rate=0,
+        col="close",
+        normalization=True,
+        **kws
     ):
         if not name:
             try:
@@ -2659,7 +2688,10 @@ class vinfo(basicinfo, indicator):
         df = get_daily(code, start=start, end=end)
         df[col] = pd.to_numeric(df[col])  # in case the col is not float
         df["totvalue"] = df[col]
-        df["netvalue"] = df[col] / df.iloc[0][col]
+        if normalization:
+            df["netvalue"] = df[col] / df.iloc[0][col]
+        else:
+            df["netvalue"] = df[col]
         self.price = df
         self.round_label = kws.get("round_label", 0)
         self.dividend_label = kws.get("dividend_label", 0)
